@@ -1,10 +1,9 @@
+use std::error::Error;
+use std::fmt::{Debug, Display};
+use std::path::PathBuf;
+use std::time::Duration;
+
 use getopts::{Fail, Matches, Options};
-use std::{
-    error::Error,
-    fmt::{Debug, Display},
-    path::PathBuf,
-    time::Duration,
-};
 
 pub const MAX_INPUT_CPLX_FLAG: &str = "max-cplx";
 pub const INPUT_FILE_FLAG: &str = "input-file";
@@ -63,6 +62,21 @@ pub struct Arguments {
     pub artifacts_folder: Option<PathBuf>,
     pub stats_folder: Option<PathBuf>,
 }
+impl Arguments {
+    pub fn for_internal_documentation_test() -> Self {
+        Self {
+            command: FuzzerCommand::Fuzz,
+            max_input_cplx: 256.,
+            maximum_duration: Duration::MAX,
+            maximum_iterations: usize::MAX,
+            stop_after_first_failure: true,
+            corpus_in: None,
+            corpus_out: None,
+            artifacts_folder: None,
+            stats_folder: None,
+        }
+    }
+}
 
 /// The command line argument parser used by the fuzz target and `cargo fuzzcheck`
 #[must_use]
@@ -140,7 +154,6 @@ pub fn options_parser() -> Options {
         .as_str(),
         "N",
     );
-
     options.optflag("h", "help", "print this help menu");
 
     options
@@ -165,7 +178,10 @@ impl Arguments {
             ));
         }
 
-        let command = matches.opt_str(COMMAND_FLAG).unwrap_or_else(|| COMMAND_FUZZ.to_owned());
+        let command = matches.opt_str(COMMAND_FLAG).unwrap_or_else(
+            #[no_coverage]
+            || COMMAND_FUZZ.to_owned(),
+        );
 
         let command = command.as_str();
 
@@ -222,7 +238,10 @@ impl Arguments {
             None
         };
 
-        let stats_folder: Option<PathBuf> = matches.opt_str(STATS_FLAG).and_then(|x| x.parse::<PathBuf>().ok());
+        let stats_folder: Option<PathBuf> = matches.opt_str(STATS_FLAG).and_then(
+            #[no_coverage]
+            |x| x.parse::<PathBuf>().ok(),
+        );
 
         let no_stats = if matches.opt_present(NO_STATS_FLAG) {
             Some(())
@@ -240,21 +259,27 @@ impl Arguments {
         let command = match command {
             COMMAND_FUZZ => FuzzerCommand::Fuzz,
             COMMAND_READ => {
-                let input_file = input_file.unwrap_or_else(|| {
-                    panic!(
-                        "An input file must be provided when reading a test case. Use --{}",
-                        INPUT_FILE_FLAG
-                    )
-                });
+                let input_file = input_file.unwrap_or_else(
+                    #[no_coverage]
+                    || {
+                        panic!(
+                            "An input file must be provided when reading a test case. Use --{}",
+                            INPUT_FILE_FLAG
+                        )
+                    },
+                );
                 FuzzerCommand::Read { input_file }
             }
             COMMAND_MINIFY_INPUT => {
-                let input_file = input_file.unwrap_or_else(|| {
-                    panic!(
-                        "An input file must be provided when minifying a test case. Use --{}",
-                        INPUT_FILE_FLAG
-                    )
-                });
+                let input_file = input_file.unwrap_or_else(
+                    #[no_coverage]
+                    || {
+                        panic!(
+                            "An input file must be provided when minifying a test case. Use --{}",
+                            INPUT_FILE_FLAG
+                        )
+                    },
+                );
                 FuzzerCommand::MinifyInput { input_file }
             }
             _ => unreachable!(),
@@ -281,7 +306,6 @@ impl Arguments {
 
         let defaults = DefaultArguments::default();
         let max_input_cplx: f64 = max_input_cplx.unwrap_or(defaults.max_input_cplx as f64);
-
         let corpus_in: Option<PathBuf> = if no_in_corpus.is_some() { None } else { corpus_in };
         let corpus_out: Option<PathBuf> = if no_out_corpus.is_some() { None } else { corpus_out };
 
@@ -305,8 +329,7 @@ impl Arguments {
 /// The “help” output of cargo-fuzzcheck
 #[no_coverage]
 pub fn help(parser: &Options) -> String {
-    let mut help = format!(
-        r##"
+    let mut help = r##"
 USAGE:
     cargo-fuzzcheck <FUZZ_TEST> [OPTIONS]
 
@@ -325,29 +348,34 @@ FUZZ_TEST:
         }}
     }}
 "##
-    );
+    .to_owned();
     help += parser.usage("").as_str();
     help += format!(
         r#"
 
 EXAMPLES:
 
-cargo-fuzzcheck target1 {fuzz}
-    Launch the fuzzer on “target1” with default options.
+cargo-fuzzcheck tests::fuzz_test1
+    Launch the fuzzer on "tests::fuzz_test1", located in the crate’s library, with default options.
 
-cargo-fuzzcheck target2 fuzz --{max_cplx} 4000 --{out_corpus} fuzz_results/out/
-    Fuzz “target2”, generating inputs of complexity no greater than 4000, 
+cargo-fuzzcheck tests::fuzz_bin --bin my_program
+    Launch the fuzzer on "tests::fuzz_bin", located in the "my_program" binary target, with default options.
+
+cargo-fuzzcheck fuzz_test2 --test my_integration_test
+    Launch the fuzzer on "fuzz_test2", located in the "my_integration_test" test target, with default options.
+
+cargo-fuzzcheck tests::fuzzit --{max_cplx} 4000 --{out_corpus} fuzz_results/out/
+    Fuzz "tests::fuzzit", generating inputs of complexity no greater than 4000, 
     and write the output corpus (i.e. the folder of most interesting test cases) 
     to fuzz_results/out/.
 
-cargo-fuzzcheck target1 {minify} --{input_file} "artifacts/crash.json"
-    Using “target1”, minify the test input defined in the file 
-    "artifacts/crash.json". It will put minified inputs in the folder 
+cargo-fuzzcheck tests::fuzz --command {minify} --{input_file} "artifacts/crash.json"
+    Using the fuzz test located at "tests::fuzz_test", minify the test input defined 
+    in the file "artifacts/crash.json". It will put minified inputs in the folder 
     artifacts/crash.minified/ and name them {{complexity}}-{{hash}}.json. 
     For example, artifacts/crash.minified/4213--8cd7777109b57b8c.json
     is a minified input of complexity 42.13.
 "#,
-        fuzz = COMMAND_FUZZ,
         minify = COMMAND_MINIFY_INPUT,
         input_file = INPUT_FILE_FLAG,
         max_cplx = MAX_INPUT_CPLX_FLAG,
